pub type PredicateSet = FxHashSet<PredicateIndex>;Expand description
A set of predicate symbols, typically used to represent a stratum or a collection of EDB/IDB predicates.
Aliased Type
pub struct PredicateSet { /* private fields */ }pub type PredicateSet = FxHashSet<PredicateIndex>;A set of predicate symbols, typically used to represent a stratum or a collection of EDB/IDB predicates.
pub struct PredicateSet { /* private fields */ }