pub struct NameTrie { /* private fields */ }Expand description
A trie over the /-separated segments of Mangle name constants.
Implementations
Sourceimpl NameTrie
impl NameTrie
pub fn new() -> Self
Sourcepub fn prefix_name(&self, name: &str) -> String
pub fn prefix_name(&self, name: &str) -> String
Finds the longest prefix of name that exists in the trie.
Returns the prefix as a name string, or /name if no prefix found.
Example: if trie contains /animal and /animal/dog, and we look up
/animal/dog/poodle, returns /animal/dog.